@@ -11,8 +11,10 @@ import pytreeclass as pytc
 
 
 class _fieldDict(dict):
-    """A dict used for `__pytree_structure__` attribute of a treeclass instance"""
+    """A dict used for `__treeclass_structure__` attribute of a treeclass instance"""
 
+    # using a regular dict will cause the following error:
+    # ValueError: The truth value of an array with more than one element is ambiguous. Use a.any() or a.all()
     def __eq__(self, other):
         return self.__dict__ == other.__dict__
 
@@ -24,7 +26,6 @@ def _tree_structure(tree) -> tuple[dict[str, Any], dict[str, Any]]:
     # that mark the tree leaves seen by JAX computations and the static(tree structure) that are
     # not seen by JAX computations. the scanning is done if the instance is not frozen.
     # otherwise the cached values are returned.
-
     static, dynamic = _fieldDict(tree.__dict__), _fieldDict()
 
     for field_item in pytc.fields(tree):
@@ -52,10 +53,10 @@ class _treeBase:
         """Unflatten rule for `jax.tree_unflatten`"""
         # using `object.__new__`` here is faster than using `cls.__new__`
         # as it avoids calling bases __new__ methods
-        # moreover , in _treeBase.__new__ we declare `__undeclared_fields__`
+        # moreover , in _treeBase.__new__ we declare `__treeclass_fields__`
         # however, using obejct we will not have this attribute,
         # so we need to add these attributes in the static, that updates the `self.__dict__``
-        # since we already have to pass `__undeclared_fields__` through flatten/unflatten
+        # since we already have to pass `__treeclass_fields__` through flatten/unflatten
         # this approach creates the attribute once.
         self = object.__new__(cls)
 
